@@ -1,14 +1,12 @@
 #!/usr/bin/perl
+#VERSION,1.10
 use Getopt::Long;
 Getopt::Long::Configure('no_ignore_case');
 
-# INSTALLED LW:
-#use LW; 
-# LOCAL LW:
-require "./plugins/LW.pm";
+# The LW require has been moved down about 40 lines...
 
 #######################################################################
-# last update: 05.30.2003
+# last update: 09.13.2003
 # --------------------------------------------------------------------#
 #                               Nikto                                 #
 # --------------------------------------------------------------------#
@@ -38,39 +36,43 @@ require "./plugins/LW.pm";
 #######################################################################
 # global var/definitions
 use vars qw/@OPTS %CLI %VARIABLES $CONTENT $ITEMCOUNT @COOKIES %FILES $CURRENT_HOST_ID $CURRENT_PORT/;
-use vars qw/%CONFIG %NIKTO %OUTPUT %METHD %RESPS %INFOS %SERVER %request %result %JAR %DATAS/;
-use vars qw/$DIV $VULS $OKTRAP $HOST %TARGETS @DBFILE @SERVERFILE @BUILDITEMS $PROXYCHECKED/;
+use vars qw/%CONFIG %NIKTO %OUTPUT %METHD %RESPS %INFOS %SERVER %request %result %JAR %DATAS %COUNTERS/;
+use vars qw/%UPDATES $DIV $VULS $OKTRAP $HOST %TARGETS @DBFILE @SERVERFILE @BUILDITEMS $PROXYCHECKED/;
 
 # setup
-$NIKTO{version}="1.30";
+$NIKTO{version}="1.31";
 $NIKTO{name}="Nikto";
+$CFG{configfile}="config.txt";
 $DIV = "-" x 75;
 my $STARTTIME=localtime();
-&load_configs;
-&find_plugins;
+load_configs();
+find_plugins();
 require "$NIKTO{plugindir}/nikto_core.plugin";
+require "$NIKTO{plugindir}/LW.pm";
 
-&general_config;
+general_config();
 
 LW::http_init_request(\%request);
-&proxy_setup;
+proxy_setup();
 
-&open_output;
+open_output();
 nprint($DIV);
 print "- $NIKTO{name} $NIKTO{version}/$NIKTO{core_version}     -     www.cirt.net\n";
 
-&set_targets;
-&load_scan_items;
+set_targets();
+load_scan_items();
 $PROXYCHECKED=0; # only do proxy_check once
 
 # actual scan for each host/port
-foreach $CURRENT_HOST_ID (keys %TARGETS)
+foreach $CURRENT_HOST_ID (sort { $a<=>$b } keys %TARGETS)
  {
-  if (&host_config) { next; }  # find ports only, move on to next host
+  $COUNTERS{hosts_completed}++;
+  if (($CLI{findonly}) && ($COUNTERS{hosts_completed} % 10) eq 0) { nprint("($COUNTERS{hosts_completed} of $COUNTERS{hosts_total})"); }
+  host_config();
+
   foreach $CURRENT_PORT ( keys %{$TARGETS{$CURRENT_HOST_ID}{ports}} )
    {
     if ($CURRENT_PORT eq "") { next; }
-#    nprint($DIV);
     $request{'whisker'}->{'host'}=$TARGETS{$CURRENT_HOST_ID}{ip};
     $request{'whisker'}->{'port'}=$CURRENT_PORT;
     $request{'whisker'}->{'ssl'}=$TARGETS{$CURRENT_HOST_ID}{ports}{$CURRENT_PORT}{ssl};
@@ -83,43 +85,52 @@ foreach $CURRENT_HOST_ID (keys %TARGETS)
     if ($CONFIG{'STATIC-COOKIE'} ne "") { $request{'Cookie'} = $CONFIG{'STATIC-COOKIE'}; }
     $VULS=0;
 
-    &proxy_check;
-    &dump_target_info;
-    &check_responses;
-    &check_cgi;
-    &set_scan_items;
-    &run_plugins;
-    &test_target;
+    proxy_check();
+    get_banner();
+
+    if ($CLI{findonly}) { 
+     my $protocol="http";
+     if ($TARGETS{$CURRENT_HOST_ID}{ports}{$CURRENT_PORT}{banner} eq "") { $TARGETS{$CURRENT_HOST_ID}{ports}{$CURRENT_PORT}{banner}="(no identification possible)"; }
+     if ($TARGETS{$CURRENT_HOST_ID}{ports}{$CURRENT_PORT}{ssl}) { $protocol .= "s"; }
+     nprint("+ Server: $protocol://$TARGETS{$CURRENT_HOST_ID}{display_name}:$CURRENT_PORT\t$TARGETS{$CURRENT_HOST_ID}{ports}{$CURRENT_PORT}{banner}");
+     next;
+    }
+
+    dump_target_info();
+    check_responses();
+    check_cgi();
+    set_scan_items();
+    run_plugins();
+    test_target();
    }
  }
 
-&close_output;
+nprint("+ $COUNTERS{hosts_total} host(s) tested");
+
+send_updates();
+close_output();
 exit;
 
 #################################################################################
-####                 Most functions moved to core.plugin                     ####
+####                  Most subs in nikto_core.plugin                         ####
 #################################################################################
 # load config file
 sub load_configs
 {
- my $configfile="config.txt";
- my $noconfig=0;
-   open(CONF,"<$configfile") || $noconfig++;
-   my @CONFILE=<CONF>;
-   close(CONF);
+ open(CONF,"<$CFG{configfile}") || print "- ERROR: Unable to open config file '$CFG{configfile}' ($!), only 1 CGI directory defined.\n";
+ my @CONFILE=<CONF>;
+ close(CONF);
 
- if ($noconfig) { print "- No config.txt file found, only 1 CGI directory defined.\n"; }
-
-  foreach my $line (@CONFILE)
-   {
-    $line =~ s/\#.*$//;
-    chomp($line);
-    $line =~ s/\s+$//;
-    $line =~ s/^\s+//;
-    if ($line eq "") { next; }
-    my @temp=split(/=/,$line,2);
-    if ($temp[0] ne "") { $CONFIG{$temp[0]}=$temp[1]; }
-   }
+ foreach my $line (@CONFILE)
+ {
+  $line =~ s/\#.*$//;
+  chomp($line);
+  $line =~ s/\s+$//;
+  $line =~ s/^\s+//;
+  if ($line eq "") { next; }
+  my @temp=split(/=/,$line,2);
+  if ($temp[0] ne "") { $CONFIG{$temp[0]}=$temp[1]; }
+ }
 
  # add CONFIG{CLIOPTS} to ARGV if defined...
  if ($CONFIG{CLIOPTS} ne "")
@@ -129,7 +140,6 @@ sub load_configs
   }
   return;
 }
-
 #################################################################################
 # find plugins directory
 sub find_plugins
